#[derive(EventGroup)]
{
// Attributes available to this derive:
#[esrc]
}
Derive an EventGroup implementation for an enum type.
This defines the EventGroup’s names as a set of each variant’s name
(each variant is expected to implement the Event trait).
An esrc(ignore) attribute may be specified on individual variants to
prevent them from being included in this set (it also allows non-Event
variants to be included in the type).